@@ -13,24 +13,23 @@ import (
 const saRolePrefix = "system:openshift:controller:"
 
 const (
-	InfraOriginNamespaceServiceAccountName                       = "origin-namespace-controller"
-	InfraServiceAccountControllerServiceAccountName              = "serviceaccount-controller"
-	InfraServiceAccountPullSecretsControllerServiceAccountName   = "serviceaccount-pull-secrets-controller"
-	InfraServiceServingCertServiceAccountName                    = "service-serving-cert-controller"
-	InfraBuildControllerServiceAccountName                       = "build-controller"
-	InfraBuildConfigChangeControllerServiceAccountName           = "build-config-change-controller"
-	InfraDeploymentConfigControllerServiceAccountName            = "deploymentconfig-controller"
-	InfraDeployerControllerServiceAccountName                    = "deployer-controller"
-	InfraImageTriggerControllerServiceAccountName                = "image-trigger-controller"
-	InfraImageImportControllerServiceAccountName                 = "image-import-controller"
-	InfraClusterQuotaReconciliationControllerServiceAccountName  = "cluster-quota-reconciliation-controller"
-	InfraUnidlingControllerServiceAccountName                    = "unidling-controller"
-	InfraServiceIngressIPControllerServiceAccountName            = "service-ingress-ip-controller"
-	InfraPersistentVolumeRecyclerControllerServiceAccountName    = "pv-recycler-controller"
-	InfraResourceQuotaControllerServiceAccountName               = "resourcequota-controller"
-	InfraDefaultRoleBindingsControllerServiceAccountName         = "default-rolebindings-controller"
-	InfraIngressToRouteControllerServiceAccountName              = "ingress-to-route-controller"
-	InfraNamespaceSecurityAllocationControllerServiceAccountName = "namespace-security-allocation-controller"
+	InfraOriginNamespaceServiceAccountName                      = "origin-namespace-controller"
+	InfraServiceAccountControllerServiceAccountName             = "serviceaccount-controller"
+	InfraServiceAccountPullSecretsControllerServiceAccountName  = "serviceaccount-pull-secrets-controller"
+	InfraServiceServingCertServiceAccountName                   = "service-serving-cert-controller"
+	InfraBuildControllerServiceAccountName                      = "build-controller"
+	InfraBuildConfigChangeControllerServiceAccountName          = "build-config-change-controller"
+	InfraDeploymentConfigControllerServiceAccountName           = "deploymentconfig-controller"
+	InfraDeployerControllerServiceAccountName                   = "deployer-controller"
+	InfraImageTriggerControllerServiceAccountName               = "image-trigger-controller"
+	InfraImageImportControllerServiceAccountName                = "image-import-controller"
+	InfraClusterQuotaReconciliationControllerServiceAccountName = "cluster-quota-reconciliation-controller"
+	InfraUnidlingControllerServiceAccountName                   = "unidling-controller"
+	InfraServiceIngressIPControllerServiceAccountName           = "service-ingress-ip-controller"
+	InfraPersistentVolumeRecyclerControllerServiceAccountName   = "pv-recycler-controller"
+	InfraResourceQuotaControllerServiceAccountName              = "resourcequota-controller"
+	InfraDefaultRoleBindingsControllerServiceAccountName        = "default-rolebindings-controller"
+	InfraIngressToRouteControllerServiceAccountName             = "ingress-to-route-controller"
 
 	// template instance controller watches for TemplateInstance object creation
 	// and instantiates templates as a result.
@@ -370,15 +369,6 @@ func init() {
 			eventsRule(),
 		},
 	})
-
-	addControllerRole(rbacv1.ClusterRole{
-		ObjectMeta: metav1.ObjectMeta{Name: saRolePrefix + InfraNamespaceSecurityAllocationControllerServiceAccountName},
-		Rules: []rbacv1.PolicyRule{
-			rbacv1helpers.NewRule("get", "create", "update").Groups(securityGroup).Resources("rangeallocations").RuleOrDie(),
-			rbacv1helpers.NewRule("get", "list", "watch", "update", "patch").Groups(kapiGroup).Resources("namespaces").RuleOrDie(),
-			eventsRule(),
-		},
-	})
 }
 
 // ControllerRoles returns the cluster roles used by controllers
