@@ -3,7 +3,7 @@ package v1
 import (
 	"k8s.io/apimachinery/pkg/runtime"
 
-	"github.com/openshift/api/quota/v1"
+	v1 "github.com/openshift/api/quota/v1"
 	"github.com/openshift/openshift-apiserver/pkg/quota/apis/quota"
 )
 
@@ -11,7 +11,6 @@ var (
 	localSchemeBuilder = runtime.NewSchemeBuilder(
 		quota.Install,
 		v1.Install,
-		AddConversionFuncs,
 		RegisterDefaults,
 	)
 	Install = localSchemeBuilder.AddToScheme
